==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/PrivateEndpointDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.PrivateEndpointDestinationArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.RuleStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Private Endpoint destination for a Private Endpoint Outbound Rule for the managed network of a machine learning workspace.
 * @property serviceResourceId
 * @property sparkEnabled
 * @property sparkStatus Status of a managed network Outbound Rule of a machine learning workspace.
 * @property subresourceTarget
 */
public data class PrivateEndpointDestinationArgs(
    public val serviceResourceId: Output<String>? = null,
    public val sparkEnabled: Output<Boolean>? = null,
    public val sparkStatus: Output<Either<String, RuleStatus>>? = null,
    public val subresourceTarget: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.PrivateEndpointDestinationArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.PrivateEndpointDestinationArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.PrivateEndpointDestinationArgs.builder()
            .serviceResourceId(serviceResourceId?.applyValue({ args0 -> args0 }))
            .sparkEnabled(sparkEnabled?.applyValue({ args0 -> args0 }))
            .sparkStatus(
                sparkStatus?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .subresourceTarget(subresourceTarget?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointDestinationArgs].
 */
@PulumiTagMarker
public class PrivateEndpointDestinationArgsBuilder internal constructor() {
    private var serviceResourceId: Output<String>? = null

    private var sparkEnabled: Output<Boolean>? = null

    private var sparkStatus: Output<Either<String, RuleStatus>>? = null

    private var subresourceTarget: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ahipfcepyoisigyr")
    public suspend fun serviceResourceId(`value`: Output<String>) {
        this.serviceResourceId = value
    }

    /**
     * @param value
     */
    @JvmName("jioemgrjgnlxovro")
    public suspend fun sparkEnabled(`value`: Output<Boolean>) {
        this.sparkEnabled = value
    }

    /**
     * @param value Status of a managed network Outbound Rule of a machine learning workspace.
     */
    @JvmName("cwvqsimeqhysdqig")
    public suspend fun sparkStatus(`value`: Output<Either<String, RuleStatus>>) {
        this.sparkStatus = value
    }

    /**
     * @param value
     */
    @JvmName("bjbvcsldyvstjoff")
    public suspend fun subresourceTarget(`value`: Output<String>) {
        this.subresourceTarget = value
    }

    /**
     * @param value
     */
    @JvmName("shwabawladtvpfed")
    public suspend fun serviceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceResourceId = mapped
    }

    /**
     * @param value
     */
    @JvmName("gtuxnehfpkvyuyjw")
    public suspend fun sparkEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sparkEnabled = mapped
    }

    /**
     * @param value Status of a managed network Outbound Rule of a machine learning workspace.
     */
    @JvmName("scnxttyodivxrntt")
    public suspend fun sparkStatus(`value`: Either<String, RuleStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sparkStatus = mapped
    }

    /**
     * @param value Status of a managed network Outbound Rule of a machine learning workspace.
     */
    @JvmName("krvuxpfdnyuvfljb")
    public fun sparkStatus(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RuleStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sparkStatus = mapped
    }

    /**
     * @param value Status of a managed network Outbound Rule of a machine learning workspace.
     */
    @JvmName("gvkorfynapjwevoa")
    public fun sparkStatus(`value`: RuleStatus) {
        val toBeMapped = Either.ofRight<String, RuleStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sparkStatus = mapped
    }

    /**
     * @param value
     */
    @JvmName("nesqnstnbqbckpqn")
    public suspend fun subresourceTarget(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subresourceTarget = mapped
    }

    internal fun build(): PrivateEndpointDestinationArgs = PrivateEndpointDestinationArgs(
        serviceResourceId = serviceResourceId,
        sparkEnabled = sparkEnabled,
        sparkStatus = sparkStatus,
        subresourceTarget = subresourceTarget,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/PrivateEndpointDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.PrivateEndpointDestinationArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.RuleStatus
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Private Endpoint destination for a Private Endpoint Outbound Rule for the managed network of a machine learning workspace.
 * @property serviceResourceId
 * @property sparkEnabled
 * @property sparkStatus Status of a managed network Outbound Rule of a machine learning workspace.
 * @property subresourceTarget
 */
public data class PrivateEndpointDestinationArgs(
    public val serviceResourceId: Output<String>? = null,
    public val sparkEnabled: Output<Boolean>? = null,
    public val sparkStatus: Output<Either<String, RuleStatus>>? = null,
    public val subresourceTarget: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.PrivateEndpointDestinationArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.PrivateEndpointDestinationArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.PrivateEndpointDestinationArgs.builder()
            .serviceResourceId(serviceResourceId?.applyValue({ args0 -> args0 }))
            .sparkEnabled(sparkEnabled?.applyValue({ args0 -> args0 }))
            .sparkStatus(
                sparkStatus?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .subresourceTarget(subresourceTarget?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointDestinationArgs].
 */
@PulumiTagMarker
public class PrivateEndpointDestinationArgsBuilder internal constructor() {
    private var serviceResourceId: Output<String>? = null

    private var sparkEnabled: Output<Boolean>? = null

    private var sparkStatus: Output<Either<String, RuleStatus>>? = null

    private var subresourceTarget: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("dbljvyauxoegutui")
    public suspend fun serviceResourceId(`value`: Output<String>) {
        this.serviceResourceId = value
    }

    /**
     * @param value
     */
    @JvmName("pfbsgevlggbuxpfv")
    public suspend fun sparkEnabled(`value`: Output<Boolean>) {
        this.sparkEnabled = value
    }

    /**
     * @param value Status of a managed network Outbound Rule of a machine learning workspace.
     */
    @JvmName("exfjhgfpiksqsive")
    public suspend fun sparkStatus(`value`: Output<Either<String, RuleStatus>>) {
        this.sparkStatus = value
    }

    /**
     * @param value
     */
    @JvmName("wuvkimwenpbyhifk")
    public suspend fun subresourceTarget(`value`: Output<String>) {
        this.subresourceTarget = value
    }

    /**
     * @param value
     */
    @JvmName("qfduttcfjimgoaai")
    public suspend fun serviceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceResourceId = mapped
    }

    /**
     * @param value
     */
    @JvmName("rxoxrjscrkoathgl")
    public suspend fun sparkEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sparkEnabled = mapped
    }

    /**
     * @param value Status of a managed network Outbound Rule of a machine learning workspace.
     */
    @JvmName("svlpgutljfhqxysd")
    public suspend fun sparkStatus(`value`: Either<String, RuleStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sparkStatus = mapped
    }

    /**
     * @param value Status of a managed network Outbound Rule of a machine learning workspace.
     */
    @JvmName("dvqkutsadyncokps")
    public fun sparkStatus(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RuleStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sparkStatus = mapped
    }

    /**
     * @param value Status of a managed network Outbound Rule of a machine learning workspace.
     */
    @JvmName("eitqlbqjjckfjcsh")
    public fun sparkStatus(`value`: RuleStatus) {
        val toBeMapped = Either.ofRight<String, RuleStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sparkStatus = mapped
    }

    /**
     * @param value
     */
    @JvmName("qlelxjeuigwetiti")
    public suspend fun subresourceTarget(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subresourceTarget = mapped
    }

    internal fun build(): PrivateEndpointDestinationArgs = PrivateEndpointDestinationArgs(
        serviceResourceId = serviceResourceId,
        sparkEnabled = sparkEnabled,
        sparkStatus = sparkStatus,
        subresourceTarget = subresourceTarget,
    )
}
